@@ -474,10 +474,15 @@ class DomainReaderTests(DomainAdminTests):
     credentials = ['domain_reader', 'system_admin']
 
 
-class ProjectAdminTests(SystemReaderTests):
+class ProjectAdminTests(SystemAdminTests):
 
     credentials = ['project_admin', 'system_admin']
 
+
+class ProjectMemberTests(SystemReaderTests):
+
+    credentials = ['project_member', 'system_admin']
+
     def test_identity_ec2_get_credential(self):
         # user can get their own credential
         user_id = self.persona.credentials.user_id
@@ -534,11 +539,6 @@ class ProjectAdminTests(SystemReaderTests):
                         user_id=self.test_user_2)
 
 
-class ProjectMemberTests(ProjectAdminTests):
-
-    credentials = ['project_member', 'system_admin']
-
-
-class ProjectReaderTests(ProjectAdminTests):
+class ProjectReaderTests(ProjectMemberTests):
 
     credentials = ['project_reader', 'system_admin']
